==> monodevelop-database_1.0%2Bdfsg.orig.tar.gz: monodevelop-database-1.0+dfsg/MonoDevelop.Database.Components/Widgets/ProjectDirectoryComboBox.cs <==
﻿//
// Authors:
//   Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//

using Gtk;
using System;
using System.Collections.Generic;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Projects;
using MonoDevelop.Projects.Gui;

namespace MonoDevelop.Database.Components
{
	public class ProjectDirectoryComboBox : ComboBox
	{
		private TreeStore store;
		
		public ProjectDirectoryComboBox ()
		{
			store = new TreeStore (typeof (Gdk.Pixbuf), typeof (string), typeof (Project), typeof (ProjectFile));
			
			CellRendererPixbuf pixbuf = new CellRendererPixbuf ();
			CellRendererText text = new CellRendererText ();

			this.PackStart (pixbuf, false);
			this.PackStart (text, false);
			this.AddAttribute (pixbuf, "pixbuf", 0);
			this.AddAttribute (text, "markup", 1);
			
			this.Model = store;
			
			PopulateCombo ();
		}
		
		public string SelectedDirectory {
			get {
				TreeIter iter;
				if (this.GetActiveIter (out iter)) {
					ProjectFile file = store.GetValue (iter, 3) as ProjectFile;
					if (file != null)
						return file.FilePath;
					
					Project proj = store.GetValue (iter, 2) as Project;
					return proj.BaseDirectory;
				}
				
				return null;
			}
		}
		
		public Project SelectedProject {
			get {
				TreeIter iter;
				if (this.GetActiveIter (out iter))
					return store.GetValue (iter, 2) as Project;
				return null;
			}
		}
		
		private void PopulateCombo ()
		{
			IconService service = (IconService) ServiceManager.GetService (typeof(IconService));
			Combine cmb = IdeApp.ProjectOperations.CurrentOpenCombine;
			if (cmb != null) {
				CombineEntry selected = IdeApp.ProjectOperations.CurrentSelectedCombineEntry;
				TreeIter activeIter = TreeIter.Zero;

				foreach (Project proj in cmb.Entries) {
					Gdk.Pixbuf pixbuf = null;
					
					if (proj is DotNetProject && (proj as DotNetProject).LanguageBinding == null) {
						pixbuf = MonoDevelop.Core.Gui.Services.Resources.GetIcon (Stock.DialogError);
					} else {
						string icon = service.GetImageForProjectType (proj.ProjectType);
						pixbuf = MonoDevelop.Core.Gui.Services.Resources.GetIcon (icon);
					}
					
					TreeIter iter = store.AppendValues (pixbuf, "<b>" + proj.Name + "</b>", proj, null);
					
					foreach (ProjectFile file in proj.ProjectFiles) {
						if (file.Subtype != Subtype.Directory)
							continue;
						
						pixbuf = MonoDevelop.Core.Gui.Services.Resources.GetIcon (Stock.Directory);
						store.AppendValues (iter, pixbuf, file.Name, proj, file);
					}
					
					if (proj == selected)
						activeIter = iter;
				}
				
				if (activeIter.Equals (TreeIter.Zero)) {
					 if (store.GetIterFirst (out activeIter))
						this.SetActiveIter (activeIter);
				} else {
					this.SetActiveIter (activeIter);
				}
			}
		}
	}
}

==> monodevelop-database_2.2%2Bdfsg.orig.tar.gz: monodevelop-database-2.2/MonoDevelop.Database.Components/Widgets/ProjectDirectoryComboBox.cs <==
//
// Authors:
//   Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//

using Gtk;
using System;
using System.IO;
using System.Collections.Generic;
using MonoDevelop.Core;
using MonoDevelop.Core.Gui;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Projects;
using MonoDevelop.Projects.Gui;

namespace MonoDevelop.Database.Components
{
	[System.ComponentModel.Category("widget")]
	[System.ComponentModel.ToolboxItem(true)]
	public class ProjectDirectoryComboBox : ComboBox
	{
		private TreeStore store;
		
		public ProjectDirectoryComboBox ()
		{
			store = new TreeStore (typeof (Gdk.Pixbuf), typeof (string), typeof (Project), typeof (string));
			
			CellRendererPixbuf pixbuf = new CellRendererPixbuf ();
			CellRendererText text = new CellRendererText ();

			this.PackStart (pixbuf, false);
			this.PackStart (text, false);
			this.AddAttribute (pixbuf, "pixbuf", 0);
			this.AddAttribute (text, "markup", 1);
			
			this.Model = store;
			
			PopulateCombo ();
		}
		
		public string SelectedDirectory {
			get {
				TreeIter iter;
				if (this.GetActiveIter (out iter))
					return store.GetValue (iter, 3) as string;
				return null;
			}
		}
		
		public Project SelectedProject {
			get {
				TreeIter iter;
				if (this.GetActiveIter (out iter))
					return store.GetValue (iter, 2) as Project;
				return null;
			}
		}
		
		private void PopulateCombo ()
		{			
			Solution cmb = IdeApp.ProjectOperations.CurrentSelectedSolution;
			if (cmb != null) {
				SolutionItem selected = IdeApp.ProjectOperations.CurrentSelectedSolutionItem;
				TreeIter activeIter = TreeIter.Zero;

				//TODO: add support for recursive combines
				foreach (SolutionItem entry in cmb.Items) {
					if (!(entry is DotNetProject))
						continue;
				
					DotNetProject proj = (DotNetProject)entry;
					Gdk.Pixbuf pixbuf = null;
					
					if (proj is DotNetProject && (proj as DotNetProject).LanguageBinding == null) {
						pixbuf = MonoDevelop.Core.Gui.ImageService.GetPixbuf (Gtk.Stock.DialogError);
					} else {
						pixbuf = MonoDevelop.Core.Gui.ImageService.GetPixbuf (proj.StockIcon, IconSize.Menu);
					}
					
					TreeIter iter = store.AppendValues (pixbuf, "<b>" + proj.Name + "</b>", proj, proj.BaseDirectory);
					PopulateCombo (iter, proj.BaseDirectory, proj);

					if (proj == selected)
						activeIter = iter;
				}
				
				if (activeIter.Equals (TreeIter.Zero)) {
					 if (store.GetIterFirst (out activeIter))
						this.SetActiveIter (activeIter);
				} else {
					this.SetActiveIter (activeIter);
				}
			}
		}
		
		private void PopulateCombo (TreeIter parent, string parentDir, Project project)
		{
			foreach (string dir in Directory.GetDirectories (parentDir)) {
				string name = System.IO.Path.GetFileName (dir);
				
				//TODO: use the ProjectFile information
				if (name == "gtk-gui" || name == "bin")
					continue;
				
				Gdk.Pixbuf pixbuf = MonoDevelop.Core.Gui.ImageService.GetPixbuf (Gtk.Stock.Directory);
				TreeIter iter = store.AppendValues (parent, pixbuf, name, project, dir);
						
				PopulateCombo (iter, dir, project);
			}
		}
	}
}
